@@ -724,15 +724,25 @@ def list_metrics(config: CLIContext, show_all_dims: bool = False, search: Option
 
 @cli.command()
 @pass_config
+@click.option("--metric-names", required=False, help="Metrics to filter dimensions by (intersection)")
 @exception_handler
-def list_dimensions(config: CLIContext) -> None:
+def list_dimensions(config: CLIContext, metric_names: Optional[str] = None) -> None:
     """List all unique dimensions for the Organization."""
+    metric_names_input: Optional[List[str]] = None
+    if metric_names:
+        metric_names_input = [m.strip() for m in metric_names.split(",")]
 
-    spinner = Halo(text="Looking for all available dimensions...", spinner="dots")
+    spinner = Halo(
+        text="Looking for all available dimensions...",
+        spinner="dots",
+    )
     spinner.start()
 
     model_key = config.resolve_query_model_key()
-    dimensions = sorted(config.mql.list_dimensions(model_key.id if model_key else None).values(), key=lambda d: d.name)
+    dimensions = sorted(
+        config.mql.list_dimensions(model_key.id if model_key else None, metric_names_input).values(),
+        key=lambda d: d.name,
+    )
     if not dimensions:
         spinner.fail("List of dimensions unavailable.")
 
